// set the dimensions and margins of the graph
const margin = {
    top: 160,
    right: 450,
    bottom: 60,
    left: 60,
  },
  width = 1000 - margin.left - margin.right,
  height = 700 - margin.top - margin.bottom;

// append the svg object to the body of the page
const svg = d3
  .select('#my_dataviz')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Define the div for the tooltip
const tooltip = d3
  .select('body')
  .append('div')
  .attr('class', 'tooltip')
  .style('opacity', 0);

//Graph Title
svg
  .append('text')
  .attr('x', width / 2)
  .attr('y', -90)
  .attr('text-anchor', 'middle')
  .text('Comparison of Bevarage Companies')
  .style('font-size', '25px');

// load and read the data
d3.csv('data.csv').then((data) => {
  // add x axis
  const x = d3
    .scaleLinear()
    .domain([0, 350])
    .range([0, width]);

  //visualize x axis
  svg
    .append('g')
    .attr('transform', `translate(0, ${height})`)
    .call(d3.axisBottom(x));

  // add x axis label
  svg
    .append('text')
    .attr('class', 'x label')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', height + 50)
    .style('font-size', '15px')
    .text('Levels of Glucose');

  // add y axis
  const y = d3
    .scaleLinear()
    .domain([0, 100])
    .range([height, 0]);

  //visualize y axis
  svg.append('g').call(d3.axisLeft(y));

  // add y axis label:
  svg
    .append('text')
    .attr('text-anchor', 'middle')
    .attr('x', -height / 2)
    .attr('y', -50)
    .text('Rating')
    .style('font-size', '15px')
    .attr('transform', 'rotate(-90)');

  // add a scale for bubble size
  const z = d3
    .scaleLinear()
    .domain([0, 150]) // max calorie size
    .range([0, 23]);

  // add a scale for bubble color
  const myColor = d3
    .scaleOrdinal()
    .domain([
      'Dew',
      'Pespsi',
      'Thumsup',
      'Sprite',
      'Coke',
      'Fanta',
      'Maaza',
    ]) // Adjust domain according to your data
    .range([
      '#1f99b4',
      '#ff5f0e',
      '#8ca04c',
      '#f19788',
      '#9456bd',
      '#8c594b',
      '#e379c2',
    ]); // Change colors as desired

  // add Bubbles
  svg
    .append('g')
    .selectAll('dot')
    .data(data)
    .join('circle')
    .attr('class', 'bubbles')
    .attr('cx', (d) => x(d.Glucose))
    .attr('cy', (d) => y(d.Rating))
    .attr('r', (d) => z(d.Calories))
    .style('fill', (d) => myColor(d.Make)) // Update to use myColor scale
    .style('opacity', '0.7')
    .attr('stroke', 'red')
    // Add tooltip interaction
    .on('mouseover', (event, d) => {
      tooltip
        .transition()
        .duration(200)
        .style('opacity', 1);
      tooltip
        .html(
          `Calories: ${d.Calories}<br/>Glucose: ${d.Glucose}`,
        )
        .style('left', event.pageX + 'px')
        .style('top', event.pageY - 28 + 'px');
    })
    .on('mouseout', () => {
      tooltip
        .transition()
        .duration(200)
        .style('opacity', 0);
    });

  //Bubble size legend
  const valuesToShow = [50, 100, 150];

  //circle sizes
  svg
    .selectAll('legend')
    .data(valuesToShow)
    .join('circle')
    .attr('cx', (d) => z(d) * 6 + 640)
    .attr('cy', (d) => height - 150 - z(d))
    .attr('r', (d) => z(d))
    .style('fill', (d) => myColor(d)) // Update to use myColor scale
    .style('opacity', '0.7');

  //Size number labels
  svg
    .append('text')
    .attr('x', 685)
    .attr('y', 355)
    .text('50')
    .style('font-size', 15)
    .attr('text-anchor', 'middle');

  svg
    .append('text')
    .attr('x', 735)
    .attr('y', 355)
    .text('100')
    .style('font-size', 15)
    .attr('text-anchor', 'middle');

  svg
    .append('text')
    .attr('x', 785)
    .attr('y', 355)
    .text('150')
    .style('font-size', 15)
    .attr('text-anchor', 'middle');

  // Size legend title
  svg
    .append('text')
    .attr('x', 740)
    .attr('y', 400)
    .text('Calorie Size')
    .style('font-size', 20)
    .attr('text-anchor', 'middle');

  //Bubble color legend
  const size = 20;
  const newgroups = [
    'Dew',
    'Sprite',
    'Thumsup',
    'Fanta',
    'Maaza',
    'Coke',
    'Pespsi',
  ];
  const myLabelColor = d3
    .scaleOrdinal()
    .domain([
      'Dew',
      'Sprite',
      'Thumsup',
      'Fanta',
      'Maaza',
      'Coke',
      'Pespsi',
    ])
    .range([
      '#1f99b4',
      '#ff5f0e',
      '#8ca04c',
      '#f19788',
      '#9456bd',
      '#8c594b',
      '#e379c2',
    ]);

  //add colored dots for legend
  svg
    .selectAll('myrect')
    .data(newgroups)
    .join('circle')
    .attr('cx', 650)
    .attr('cy', (d, i) => 10 + i * (size + 7))
    .attr('r', 5)
    .style('fill', (d) => myLabelColor(d))
    .style('opacity', '0.7')
    .attr('stroke', 'black');

  // add labels beside colored dots
  svg
    .selectAll('mylabels')
    .data(newgroups)
    .enter()
    .append('text')
    .attr('x', 680)
    .attr('y', (d, i) => 10 + i * (size + 7))
    .style('fill', (d) => myLabelColor(d))
    .text((d) => d)
    .attr('text-anchor', 'left')
    .style('alignment-baseline', 'middle');

  //color legend title
  svg
    .append('text')
    .attr('x', 740)
    .attr('y', -20)
    .text('Bevarages:')
    .style('font-size', 18)
    .attr('text-anchor', 'middle');
});
